==> zhongyan-activity-service-api-1.0.3-20211202.090937-111-sources.jar: cn/com/duiba/zhongyan/activity/service/api/utils/ExcelExportUtil.java <==
package cn.com.duiba.zhongyan.activity.service.api.utils;

import cn.com.duiba.wolf.utils.DateUtils;
import cn.com.duiba.zhongyan.activity.service.api.base.BizRuntimeException;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.ActivityDetailExcelDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.SurveyDataExcelDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.WinPrizeHeadExcelDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.WinnerRecordDTO;
import cn.com.duiba.zhongyan.activity.service.api.param.*;
import com.alibaba.excel.EasyExcelFactory;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.metadata.BaseRowModel;
import com.alibaba.excel.metadata.Sheet;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

public class ExcelExportUtil {

    public static final Logger logger = LoggerFactory.getLogger(ExcelExportUtil.class);

    public static final String outPath = "";

    public static ExcelWriter writer=null;

    public static WriteSheet writeSheet=null;

    public static OutputStream outputStream=null;

    //表头字段
    public static final List<String> answerPageHeadList = new ArrayList<String>() {
        {
            add("OpenID");
            add("UnionID");
            add("用户昵称");
            add("答题时间");
            add("所属地区");
            add("用户标签");
            add("答题时长");
        }
    };

    public static void initAnswerExport(List<AnswerPageRecordParam> answerPageRecordParamList,OutputStream out){
        outputStream=out;
        List<Integer> questionNum = answerPageRecordParamList.stream().map(answerPage -> {
            AnswerPageParam answerPageParam = JSONObject.parseObject(answerPage.getAnswerContent(), AnswerPageParam.class);
            return answerPageParam.getQuestionList().size();
        }).collect(Collectors.toList());
        //最大题目数
        Integer max = Collections.max(questionNum);

        for (int i = 1; i <= max; i++) {
            answerPageHeadList.add(String.format("题目%s", i));
            answerPageHeadList.add(String.format("答案%s", i));
        }

        //所有表头行集合
        ArrayList<List<String>> headList = new ArrayList<>();
        headList.add(answerPageHeadList);
        writer = EasyExcelFactory.write(outputStream).head(headList).build();
        writeSheet = EasyExcelFactory.writerSheet("中奖记录").build();
    }

    public static void close(){
        try {
            if(Objects.nonNull(writer)){
                writer.finish();
            }
            if(Objects.nonNull(outputStream)){
                outputStream.close();
            }
        } catch (IOException e) {
            logger.error("导出失败",e);
        }
    }

    /**
     * 答卷导出
     *
     * @param answerPageRecordParamList
     * @throws Exception
     */
    public static void exportAnswerPage(List<AnswerPageRecordParam> answerPageRecordParamList) throws Exception{

        if (CollectionUtils.isEmpty(answerPageRecordParamList)) {
            logger.info("无数据或数据导出完毕");
            return;
        }

        //行数据
        List<List<Object>> list = answerPageRecordParamList.stream().map(answerPageRecord -> {
            List<Object> row = new ArrayList<>();
            row.add(answerPageRecord.getOpenId());
            row.add(answerPageRecord.getUnionId());
            row.add(answerPageRecord.getNick());
            //TODO Long转格式化时间
            row.add(answerPageRecord.getAnswerTime());
            row.add(answerPageRecord.getRegion());
            row.add(answerPageRecord.getUserTagStr());
            row.add(answerPageRecord.getAnswerDuration());
            AnswerPageParam answerPage = JSONObject.parseObject(answerPageRecord.getAnswerContent(), AnswerPageParam.class);
            //题目
            List<QuestionAnswerParam> questionList = answerPage.getQuestionList();
            questionList.forEach(question -> {
                row.add(question.getTitle());
                //答案
                String answer = question.getAnswerList().stream().map(answerContent -> {
                    //选择题
                    if (question.getType() != 2) {
                        //选择题答案
                        if (StringUtils.isBlank(answerContent.getRequiredAnswer())) {
                            return answerContent.getAnswer();
                        }
                        //选择答案+必填框答案
                        return String.format(answerContent.getAnswer() + "-%s", answerContent.getRequiredAnswer());
                    }
                    //填空题答案
                    return answerContent.getAnswer();

                }).collect(Collectors.joining(";"));
                row.add(answer);
            });
            return row;
        }).collect(Collectors.toList());

        writer.write(list,writeSheet);
    }

    /**
     * 中奖用户导出，init后循环获取分页数据写入输出流，最后关闭流
     *
     * @param winnerRecordDtoList
     */
    public static void winPrizeUserExport(List<WinnerRecordDTO> winnerRecordDtoList) {
        if (CollectionUtils.isEmpty(winnerRecordDtoList)) {
            throw new BizRuntimeException("没有数据导出");
        }

        List<WinPrizeHeadExcelDTO> data = new ArrayList<>();
        winnerRecordDtoList.forEach(prize -> {
            WinPrizeHeadExcelDTO winPrizeHeadExcelDTO = new WinPrizeHeadExcelDTO();
            winPrizeHeadExcelDTO.setOpenId(prize.getOpenId());
            winPrizeHeadExcelDTO.setUnionID(prize.getUnionId());
            winPrizeHeadExcelDTO.setNick(prize.getNickName());
            winPrizeHeadExcelDTO.setPrize(prize.getPrizeName());
            winPrizeHeadExcelDTO.setPrizeStatus("");
            winPrizeHeadExcelDTO.setReceiveTime(prize.getReceiveTime());
            winPrizeHeadExcelDTO.setOrderId(prize.getOrderId().toString());
            winPrizeHeadExcelDTO.setUsername(prize.getUsername());
            winPrizeHeadExcelDTO.setPhone(prize.getPhone());
            winPrizeHeadExcelDTO.setAddress(prize.getAddress());
            data.add(winPrizeHeadExcelDTO);
        });
        writer.write(data,writeSheet);
    }


    /**
     * 活动明细导出
     * @param dataStatisticsParams
     */
    public static void activityDetailExport(List<DataStatisticsParam> dataStatisticsParams){
        if (CollectionUtils.isEmpty(dataStatisticsParams)){
            throw new BizRuntimeException("无数据导出");
        }
        ArrayList<ActivityDetailExcelDTO> data = new ArrayList<>();
        dataStatisticsParams.forEach(x ->{
            ActivityDetailExcelDTO activityDetailExcelDTO = new ActivityDetailExcelDTO();
            activityDetailExcelDTO.setDate(DateUtils.getDayStr(x.getSyncTime()));
            activityDetailExcelDTO.setJoinPv(x.getJoinPv());
            activityDetailExcelDTO.setJoinUv(x.getJoinUv());
            activityDetailExcelDTO.setVisitPv(x.getVisitPv());
            activityDetailExcelDTO.setVisitUv(x.getVisitUv());
            activityDetailExcelDTO.setSubmitCount(x.getSubmitCount());
            activityDetailExcelDTO.setCompletion(x.getCompletion());
            data.add(activityDetailExcelDTO);
        });
        writer.write(data, writeSheet);
    }

    public static void surveyDataExport(List<SurveyDataParam> surveyDataParams){
        if (CollectionUtils.isEmpty(surveyDataParams)){
            throw new BizRuntimeException("无数据导出");
        }
        ArrayList<SurveyDataExcelDTO> data = new ArrayList<>();
        surveyDataParams.forEach(x ->{
            SurveyDataExcelDTO surveyDataExcelDTO = new SurveyDataExcelDTO();
            surveyDataExcelDTO.setOption(x.getOption());
            surveyDataExcelDTO.setCount(x.getCount());
            surveyDataExcelDTO.setTitle(x.getTitle());
            surveyDataExcelDTO.setRatio(x.getRatio());
            data.add(surveyDataExcelDTO);
        });
        writer.write(data, writeSheet);
    }

    /**
     * 初始化excel导出
     * @param out 输出流
     * @param sheetName sheet页名
     */
    public static void init(OutputStream out,String sheetName){
        outputStream=out;
        writer = EasyExcelFactory.write(outputStream, WinPrizeHeadExcelDTO.class).build();
        writeSheet = EasyExcelFactory.writerSheet(sheetName).build();
    }

    public static void writeWithTemplateAndSheet(String fileName, List<? extends BaseRowModel> data, Sheet sheet) {
        if (CollectionUtils.isEmpty(data)) {
            return;
        }

        sheet = (sheet != null) ? sheet : new Sheet(0, 1);
        sheet.setClazz(data.get(0).getClass());

        OutputStream outputStream = null;
        ExcelWriter writer = null;
        try {
            outputStream = new FileOutputStream(outPath + fileName);
            writer = EasyExcelFactory.getWriter(outputStream);
            writer.write(data, sheet);
        } catch (FileNotFoundException e) {
            logger.error("找不到文件或文件路径错误, 文件：{}", outPath + fileName);
        } finally {
            try {
                if (writer != null) {
                    writer.finish();
                }
                if (outputStream != null) {
                    outputStream.close();
                }
            } catch (IOException e) {
                logger.error("excel文件导出失败, 失败原因：{}", e);
            }
        }
    }


}

==> zhongyan-activity-service-api-1.0.3-20211203.125705-173-sources.jar: cn/com/duiba/zhongyan/activity/service/api/utils/ExcelExportUtil.java <==
package cn.com.duiba.zhongyan.activity.service.api.utils;

import cn.com.duiba.wolf.utils.DateUtils;
import cn.com.duiba.zhongyan.activity.service.api.base.BizRuntimeException;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.ActivityDetailExcelDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.SurveyDataExcelDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.WinPrizeHeadExcelDTO;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.WinnerRecordDTO;
import cn.com.duiba.zhongyan.activity.service.api.enums.PrizeStatusEnum;
import cn.com.duiba.zhongyan.activity.service.api.param.*;
import com.alibaba.excel.EasyExcelFactory;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.metadata.BaseRowModel;
import com.alibaba.excel.metadata.Sheet;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

public class ExcelExportUtil {

    public static final Logger logger = LoggerFactory.getLogger(ExcelExportUtil.class);

    public static final String outPath = "";

    public static ExcelWriter writer=null;

    public static WriteSheet writeSheet=null;

    public static OutputStream outputStream=null;

    //表头字段
    public static final List<String> answerPageHeadList = new ArrayList<String>() {
        {
            add("OpenID");
            add("UnionID");
            add("用户昵称");
            add("答题时间");
            add("所属地区");
            add("用户标签");
            add("答题时长");
        }
    };

    public void initAnswerExport(Integer questionNum,OutputStream out){
        List<List<String>> headList= new ArrayList<>();
        headList.add(Lists.newArrayList("OpenID"));
        headList.add(Lists.newArrayList("UnionID"));
        headList.add(Lists.newArrayList("用户昵称"));
        headList.add(Lists.newArrayList("答题时间"));
        headList.add(Lists.newArrayList("所属地区"));
        headList.add(Lists.newArrayList("用户标签"));
        headList.add(Lists.newArrayList("答题时长"));
        outputStream=out;

        for (int i = 1; i <= questionNum; i++) {
            headList.add(Lists.newArrayList(String.format("题目%s", i)));
            headList.add(Lists.newArrayList(String.format("答案%s", i)));
        }

        writer = EasyExcelFactory.write(outputStream).head(headList).build();
        writeSheet = EasyExcelFactory.writerSheet("答卷列表").build();
    }

    public void close(){
        try {
            if(Objects.nonNull(writer)){
                writer.finish();
            }
            if(Objects.nonNull(outputStream)){
                outputStream.close();
            }
        } catch (IOException e) {
            logger.error("导出失败",e);
        }
    }

    /**
     * 答卷导出
     *
     * @param answerPageRecordParamList
     * @throws Exception
     */
    public void exportAnswerPage(List<AnswerPageRecordParam> answerPageRecordParamList) throws Exception{

        if (CollectionUtils.isEmpty(answerPageRecordParamList)) {
            logger.info("无数据或数据导出完毕");
            return;
        }

        //行数据
        List<List<Object>> list = answerPageRecordParamList.stream().map(answerPageRecord -> {
            List<Object> row = new ArrayList<>();
            row.add(answerPageRecord.getOpenId());
            row.add(answerPageRecord.getUnionId());
            row.add(answerPageRecord.getNick());
            row.add(answerPageRecord.getAnswerTime());
            row.add(answerPageRecord.getRegion());
            row.add(answerPageRecord.getUserTagStr());
            row.add(answerPageRecord.getAnswerDuration());
            AnswerPageParam answerPage = JSONObject.parseObject(answerPageRecord.getAnswerContent(), AnswerPageParam.class);
            //题目
            List<QuestionAnswerParam> questionList = answerPage.getQuestionList();
            questionList.forEach(question -> {
                row.add(question.getTitle());
                //答案
                String answer = question.getAnswerList().stream().map(answerContent -> {
                    //选择题
                    if (question.getType() != 2) {
                        //选择题答案
                        if (StringUtils.isBlank(answerContent.getRequiredAnswer())) {
                            return answerContent.getAnswer();
                        }
                        //选择答案+必填框答案
                        return String.format(answerContent.getAnswer() + "-%s", answerContent.getRequiredAnswer());
                    }
                    //填空题答案
                    return answerContent.getAnswer();

                }).collect(Collectors.joining(";"));
                row.add(answer);
            });
            return row;
        }).collect(Collectors.toList());

        writer.write(list,writeSheet);
    }

    /**
     * 中奖用户导出，init后循环获取分页数据写入输出流，最后关闭流
     *
     * @param winnerRecordDtoList
     */
    public void winPrizeUserExport(List<WinnerRecordDTO> winnerRecordDtoList) {
        if (CollectionUtils.isEmpty(winnerRecordDtoList)) {
            throw new BizRuntimeException("没有数据导出");
        }

        List<WinPrizeHeadExcelDTO> data = new ArrayList<>();
        winnerRecordDtoList.forEach(prize -> {
            WinPrizeHeadExcelDTO winPrizeHeadExcelDTO = new WinPrizeHeadExcelDTO();
            winPrizeHeadExcelDTO.setOpenId(prize.getOpenId());
            winPrizeHeadExcelDTO.setUnionID(prize.getUnionId());
            winPrizeHeadExcelDTO.setNick(prize.getNickName());
            winPrizeHeadExcelDTO.setPrize(prize.getPrizeName());
            winPrizeHeadExcelDTO.setPrizeStatus(PrizeStatusEnum.getDescByStatus(prize.getPrizeStatus()));
            winPrizeHeadExcelDTO.setReceiveTime(prize.getReceiveTime());
            winPrizeHeadExcelDTO.setOrderId(prize.getOrderId());
            winPrizeHeadExcelDTO.setUsername(prize.getUsername());
            winPrizeHeadExcelDTO.setPhone(prize.getPhone());
            winPrizeHeadExcelDTO.setAddress(prize.getAddress());
            data.add(winPrizeHeadExcelDTO);
        });
        writer.write(data,writeSheet);
    }


    /**
     * 活动明细导出
     * @param dataStatisticsParams
     */
    public static void activityDetailExport(List<DataStatisticsParam> dataStatisticsParams){
        if (CollectionUtils.isEmpty(dataStatisticsParams)){
            throw new BizRuntimeException("无数据导出");
        }
        ArrayList<ActivityDetailExcelDTO> data = new ArrayList<>();
        dataStatisticsParams.forEach(x ->{
            ActivityDetailExcelDTO activityDetailExcelDTO = new ActivityDetailExcelDTO();
            activityDetailExcelDTO.setDate(DateUtils.getDayStr(x.getSyncTime()));
            activityDetailExcelDTO.setJoinPv(x.getJoinPv());
            activityDetailExcelDTO.setJoinUv(x.getJoinUv());
            activityDetailExcelDTO.setVisitPv(x.getVisitPv());
            activityDetailExcelDTO.setVisitUv(x.getVisitUv());
            activityDetailExcelDTO.setSubmitCount(x.getSubmitCount());
            activityDetailExcelDTO.setCompletion(x.getCompletion());
            data.add(activityDetailExcelDTO);
        });
        writer.write(data, writeSheet);
    }

    public static void surveyDataExport(List<SurveyDataParam> surveyDataParams){
        if (CollectionUtils.isEmpty(surveyDataParams)){
            throw new BizRuntimeException("无数据导出");
        }
        ArrayList<SurveyDataExcelDTO> data = new ArrayList<>();
        surveyDataParams.forEach(x ->{
            SurveyDataExcelDTO surveyDataExcelDTO = new SurveyDataExcelDTO();
            surveyDataExcelDTO.setOption(x.getOption());
            surveyDataExcelDTO.setCount(x.getCount());
            surveyDataExcelDTO.setTitle(x.getTitle());
            surveyDataExcelDTO.setRatio(x.getRatio());
            data.add(surveyDataExcelDTO);
        });
        writer.write(data, writeSheet);
    }

    /**
     * 初始化excel导出
     * @param out 输出流
     * @param sheetName sheet页名
     */
    public void init(OutputStream out,String sheetName){
        outputStream=out;
        writer = EasyExcelFactory.write(outputStream, WinPrizeHeadExcelDTO.class).build();
        writeSheet = EasyExcelFactory.writerSheet(sheetName).build();
    }

    public static void writeWithTemplateAndSheet(String fileName, List<? extends BaseRowModel> data, Sheet sheet) {
        if (CollectionUtils.isEmpty(data)) {
            return;
        }

        sheet = (sheet != null) ? sheet : new Sheet(0, 1);
        sheet.setClazz(data.get(0).getClass());

        OutputStream outputStream = null;
        ExcelWriter writer = null;
        try {
            outputStream = new FileOutputStream(outPath + fileName);
            writer = EasyExcelFactory.getWriter(outputStream);
            writer.write(data, sheet);
        } catch (FileNotFoundException e) {
            logger.error("找不到文件或文件路径错误, 文件：{}", outPath + fileName);
        } finally {
            try {
                if (writer != null) {
                    writer.finish();
                }
                if (outputStream != null) {
                    outputStream.close();
                }
            } catch (IOException e) {
                logger.error("excel文件导出失败, 失败原因：{}", e);
            }
        }
    }


}
